@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Duadua::Parser;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 my @PARSER_PROC_LIST = qw/
     Duadua::Parser::Browser::MicrosoftEdge
@@ -43,14 +43,18 @@ my @PARSER_PROC_LIST = qw/
     Duadua::Parser::Browser::DuckDuckGo
     Duadua::Parser::Bot::OracleGrapeshotCrawler
     Duadua::Parser::Bot::MailRUBot
+    Duadua::Parser::Browser::PaleMoon
     Duadua::Parser::Browser::UCBrowser
     Duadua::Parser::Browser::BrowserMisc
 
     Duadua::Parser::Bot::YahooJapanBot
     Duadua::Parser::Bot::HatenaBot
     Duadua::Parser::Bot::Feedly
+    Duadua::Parser::Bot::Inoreader
     Duadua::Parser::Bot::Fastladder
     Duadua::Parser::FeaturePhone::FeaturePhone
+    Duadua::Parser::Bot::Netcraft
+    Duadua::Parser::Bot::Barkrowler
 /;
 
 sub new {
@@ -287,7 +291,7 @@ The list of User Agent Parser
 
 =begin html
 
-<a href="https://github.com/bayashi/Duadua/blob/master/LICENSE"><img src="https://img.shields.io/badge/LICENSE-Artistic%202.0-GREEN.png"></a> <a href="https://github.com/bayashi/Duadua/actions"><img src="https://github.com/bayashi/Duadua/workflows/build/badge.svg?_t=1580446038&branch=master"/></a> <a href="https://coveralls.io/r/bayashi/Duadua"><img src="https://coveralls.io/repos/bayashi/Duadua/badge.png?_t=1580446038&branch=master"/></a>
+<a href="https://github.com/bayashi/Duadua/blob/master/LICENSE"><img src="https://img.shields.io/badge/LICENSE-Artistic%202.0-GREEN.png"></a> <a href="https://github.com/bayashi/Duadua/actions"><img src="https://github.com/bayashi/Duadua/workflows/build/badge.svg?_t=1580479473&branch=master"/></a> <a href="https://coveralls.io/r/bayashi/Duadua"><img src="https://coveralls.io/repos/bayashi/Duadua/badge.png?_t=1580479473&branch=master"/></a>
 
 =end html
 
